/******************************************************************************
* Copyright (c) 2018 - 2022 Xilinx, Inc. All rights reserved.
* Copyright (c) 2022 - 2024 Advanced Micro Devices, Inc. All Rights Reserved.
* SPDX-License-Identifier: MIT
******************************************************************************/

/*
 * This is an automatically generated file from script.
 * Please do not modify this!
 */

#ifndef XPM_PINFUNC_PLAT_H_
#define XPM_PINFUNC_PLAT_H_

#ifdef __cplusplus
extern "C" {
#endif
enum PmPinGrpIds {
	PIN_GRP_SD0_0 = 0,
	PIN_GRP_SD0_1 = 1,
	PIN_GRP_SD1_0 = 2,
	PIN_GRP_SD1_1 = 3,
	PIN_GRP_SMP_0 = 4,
	PIN_GRP_SMP_1 = 5,
	PIN_GRP_SMP_2 = 6,
	PIN_GRP_SMP_3 = 7,
	PIN_GRP_SMP_4 = 8,
	PIN_GRP_SMP_5 = 9,
	PIN_GRP_CAN0_0 = 10,
	PIN_GRP_CAN0_1 = 11,
	PIN_GRP_CAN0_2 = 12,
	PIN_GRP_CAN0_3 = 13,
	PIN_GRP_CAN0_4 = 14,
	PIN_GRP_CAN0_5 = 15,
	PIN_GRP_CAN0_6 = 16,
	PIN_GRP_CAN0_7 = 17,
	PIN_GRP_CAN0_8 = 18,
	PIN_GRP_CAN0_9 = 19,
	PIN_GRP_CAN1_0 = 20,
	PIN_GRP_CAN1_1 = 21,
	PIN_GRP_CAN1_2 = 22,
	PIN_GRP_CAN1_3 = 23,
	PIN_GRP_CAN1_4 = 24,
	PIN_GRP_CAN1_5 = 25,
	PIN_GRP_CAN1_6 = 26,
	PIN_GRP_CAN1_7 = 27,
	PIN_GRP_CAN1_8 = 28,
	PIN_GRP_CAN1_9 = 29,
	PIN_GRP_GEM0_0 = 30,
	PIN_GRP_GEM0_1 = 31,
	PIN_GRP_GEM1_0 = 32,
	PIN_GRP_GEM1_1 = 33,
	PIN_GRP_I2C0_0 = 34,
	PIN_GRP_I2C0_1 = 35,
	PIN_GRP_I2C0_2 = 36,
	PIN_GRP_I2C0_3 = 37,
	PIN_GRP_I2C0_4 = 38,
	PIN_GRP_I2C0_5 = 39,
	PIN_GRP_I2C0_6 = 40,
	PIN_GRP_I2C0_7 = 41,
	PIN_GRP_I2C0_8 = 42,
	PIN_GRP_I2C0_9 = 43,
	PIN_GRP_I2C1_0 = 44,
	PIN_GRP_I2C1_1 = 45,
	PIN_GRP_I2C1_2 = 46,
	PIN_GRP_I2C1_3 = 47,
	PIN_GRP_I2C1_4 = 48,
	PIN_GRP_I2C1_5 = 49,
	PIN_GRP_I2C1_6 = 50,
	PIN_GRP_I2C1_7 = 51,
	PIN_GRP_I2C1_8 = 52,
	PIN_GRP_I2C1_9 = 53,
	PIN_GRP_SPI0_0 = 54,
	PIN_GRP_SPI0_1 = 55,
	PIN_GRP_SPI0_2 = 56,
	PIN_GRP_SPI0_3 = 57,
	PIN_GRP_SPI0_4 = 58,
	PIN_GRP_SPI0_5 = 59,
	PIN_GRP_SPI1_0 = 60,
	PIN_GRP_SPI1_1 = 61,
	PIN_GRP_SPI1_2 = 62,
	PIN_GRP_SPI1_3 = 63,
	PIN_GRP_SPI1_4 = 64,
	PIN_GRP_SPI1_5 = 65,
	PIN_GRP_USB0_0 = 66,
	PIN_GRP_USB1_0 = 67,
	PIN_GRP_CAN0_10 = 68,
	PIN_GRP_CAN0_11 = 69,
	PIN_GRP_CAN0_12 = 70,
	PIN_GRP_CAN0_13 = 71,
	PIN_GRP_CAN0_14 = 72,
	PIN_GRP_CAN0_15 = 73,
	PIN_GRP_CAN0_16 = 74,
	PIN_GRP_CAN0_17 = 75,
	PIN_GRP_CAN1_10 = 76,
	PIN_GRP_CAN1_11 = 77,
	PIN_GRP_CAN1_12 = 78,
	PIN_GRP_CAN1_13 = 79,
	PIN_GRP_CAN1_14 = 80,
	PIN_GRP_CAN1_15 = 81,
	PIN_GRP_CAN1_16 = 82,
	PIN_GRP_CAN1_17 = 83,
	PIN_GRP_CAN1_18 = 84,
	PIN_GRP_EMIO0_0 = 85,
	PIN_GRP_GPIO0_0 = 86,
	PIN_GRP_GPIO0_1 = 87,
	PIN_GRP_GPIO0_2 = 88,
	PIN_GRP_GPIO0_3 = 89,
	PIN_GRP_GPIO0_4 = 90,
	PIN_GRP_GPIO0_5 = 91,
	PIN_GRP_GPIO0_6 = 92,
	PIN_GRP_GPIO0_7 = 93,
	PIN_GRP_GPIO0_8 = 94,
	PIN_GRP_GPIO0_9 = 95,
	PIN_GRP_GPIO1_0 = 96,
	PIN_GRP_GPIO1_1 = 97,
	PIN_GRP_GPIO1_2 = 98,
	PIN_GRP_GPIO1_3 = 99,
	PIN_GRP_GPIO1_4 = 100,
	PIN_GRP_GPIO1_5 = 101,
	PIN_GRP_GPIO1_6 = 102,
	PIN_GRP_GPIO1_7 = 103,
	PIN_GRP_GPIO1_8 = 104,
	PIN_GRP_GPIO1_9 = 105,
	PIN_GRP_GPIO2_0 = 106,
	PIN_GRP_GPIO2_1 = 107,
	PIN_GRP_GPIO2_2 = 108,
	PIN_GRP_GPIO2_3 = 109,
	PIN_GRP_GPIO2_4 = 110,
	PIN_GRP_GPIO2_5 = 111,
	PIN_GRP_GPIO2_6 = 112,
	PIN_GRP_GPIO2_7 = 113,
	PIN_GRP_GPIO2_8 = 114,
	PIN_GRP_GPIO2_9 = 115,
	PIN_GRP_I2C0_10 = 116,
	PIN_GRP_I2C0_11 = 117,
	PIN_GRP_I2C0_12 = 118,
	PIN_GRP_I2C0_13 = 119,
	PIN_GRP_I2C0_14 = 120,
	PIN_GRP_I2C0_15 = 121,
	PIN_GRP_I2C0_16 = 122,
	PIN_GRP_I2C0_17 = 123,
	PIN_GRP_I2C1_10 = 124,
	PIN_GRP_I2C1_11 = 125,
	PIN_GRP_I2C1_12 = 126,
	PIN_GRP_I2C1_13 = 127,
	PIN_GRP_I2C1_14 = 128,
	PIN_GRP_I2C1_15 = 129,
	PIN_GRP_I2C1_16 = 130,
	PIN_GRP_I2C1_17 = 131,
	PIN_GRP_I2C1_18 = 132,
	PIN_GRP_MDIO0_0 = 133,
	PIN_GRP_MDIO0_1 = 134,
	PIN_GRP_MDIO1_0 = 135,
	PIN_GRP_MDIO1_1 = 136,
	PIN_GRP_OSPI0_0 = 137,
	PIN_GRP_PCIE0_0 = 138,
	PIN_GRP_PCIE0_1 = 139,
	PIN_GRP_PCIE0_2 = 140,
	PIN_GRP_QSPI0_0 = 141,
	PIN_GRP_SMAP0_0 = 142,
	PIN_GRP_UART0_0 = 143,
	PIN_GRP_UART0_1 = 144,
	PIN_GRP_UART0_2 = 145,
	PIN_GRP_UART0_3 = 146,
	PIN_GRP_UART0_4 = 147,
	PIN_GRP_UART0_5 = 148,
	PIN_GRP_UART0_6 = 149,
	PIN_GRP_UART0_7 = 150,
	PIN_GRP_UART0_8 = 151,
	PIN_GRP_UART1_0 = 152,
	PIN_GRP_UART1_1 = 153,
	PIN_GRP_UART1_2 = 154,
	PIN_GRP_UART1_3 = 155,
	PIN_GRP_UART1_4 = 156,
	PIN_GRP_UART1_5 = 157,
	PIN_GRP_UART1_6 = 158,
	PIN_GRP_UART1_7 = 159,
	PIN_GRP_UART1_8 = 160,
	PIN_GRP_WWDT0_0 = 161,
	PIN_GRP_WWDT0_1 = 162,
	PIN_GRP_WWDT0_2 = 163,
	PIN_GRP_WWDT0_3 = 164,
	PIN_GRP_WWDT0_4 = 165,
	PIN_GRP_WWDT0_5 = 166,
	PIN_GRP_WWDT0_6 = 167,
	PIN_GRP_WWDT0_7 = 168,
	PIN_GRP_WWDT1_0 = 169,
	PIN_GRP_WWDT1_1 = 170,
	PIN_GRP_WWDT1_2 = 171,
	PIN_GRP_WWDT1_3 = 172,
	PIN_GRP_WWDT1_4 = 173,
	PIN_GRP_WWDT1_5 = 174,
	PIN_GRP_WWDT1_6 = 175,
	PIN_GRP_GPIO0_10 = 176,
	PIN_GRP_GPIO0_11 = 177,
	PIN_GRP_GPIO0_12 = 178,
	PIN_GRP_GPIO0_13 = 179,
	PIN_GRP_GPIO0_14 = 180,
	PIN_GRP_GPIO0_15 = 181,
	PIN_GRP_GPIO0_16 = 182,
	PIN_GRP_GPIO0_17 = 183,
	PIN_GRP_GPIO0_18 = 184,
	PIN_GRP_GPIO0_19 = 185,
	PIN_GRP_GPIO0_20 = 186,
	PIN_GRP_GPIO0_21 = 187,
	PIN_GRP_GPIO0_22 = 188,
	PIN_GRP_GPIO0_23 = 189,
	PIN_GRP_GPIO0_24 = 190,
	PIN_GRP_GPIO0_25 = 191,
	PIN_GRP_GPIO1_10 = 192,
	PIN_GRP_GPIO1_11 = 193,
	PIN_GRP_GPIO1_12 = 194,
	PIN_GRP_GPIO1_13 = 195,
	PIN_GRP_GPIO1_14 = 196,
	PIN_GRP_GPIO1_15 = 197,
	PIN_GRP_GPIO1_16 = 198,
	PIN_GRP_GPIO1_17 = 199,
	PIN_GRP_GPIO1_18 = 200,
	PIN_GRP_GPIO1_19 = 201,
	PIN_GRP_GPIO1_20 = 202,
	PIN_GRP_GPIO1_21 = 203,
	PIN_GRP_GPIO1_22 = 204,
	PIN_GRP_GPIO1_23 = 205,
	PIN_GRP_GPIO1_24 = 206,
	PIN_GRP_GPIO1_25 = 207,
	PIN_GRP_GPIO2_10 = 208,
	PIN_GRP_GPIO2_11 = 209,
	PIN_GRP_GPIO2_12 = 210,
	PIN_GRP_GPIO2_13 = 211,
	PIN_GRP_GPIO2_14 = 212,
	PIN_GRP_GPIO2_15 = 213,
	PIN_GRP_GPIO2_16 = 214,
	PIN_GRP_GPIO2_17 = 215,
	PIN_GRP_GPIO2_18 = 216,
	PIN_GRP_GPIO2_19 = 217,
	PIN_GRP_GPIO2_20 = 218,
	PIN_GRP_GPIO2_21 = 219,
	PIN_GRP_GPIO2_22 = 220,
	PIN_GRP_GPIO2_23 = 221,
	PIN_GRP_GPIO2_24 = 222,
	PIN_GRP_GPIO2_25 = 223,
	PIN_GRP_SD0_CD_0 = 224,
	PIN_GRP_SD0_CD_1 = 225,
	PIN_GRP_SD0_PC_0 = 226,
	PIN_GRP_SD0_PC_1 = 227,
	PIN_GRP_SD0_WP_0 = 228,
	PIN_GRP_SD0_WP_1 = 229,
	PIN_GRP_SD1_PC_0 = 230,
	PIN_GRP_SD1_PC_1 = 231,
	PIN_GRP_TRACE0_0 = 232,
	PIN_GRP_TRACE0_1 = 233,
	PIN_GRP_TRACE0_2 = 234,
	PIN_GRP_SD1_DQS_0 = 235,
	PIN_GRP_SD1_DQS_1 = 236,
	PIN_GRP_SPI0_SS_0 = 237,
	PIN_GRP_SPI0_SS_1 = 238,
	PIN_GRP_SPI0_SS_2 = 239,
	PIN_GRP_SPI0_SS_3 = 240,
	PIN_GRP_SPI0_SS_4 = 241,
	PIN_GRP_SPI0_SS_5 = 242,
	PIN_GRP_SPI1_SS_0 = 243,
	PIN_GRP_SPI1_SS_1 = 244,
	PIN_GRP_SPI1_SS_2 = 245,
	PIN_GRP_SPI1_SS_3 = 246,
	PIN_GRP_SPI1_SS_4 = 247,
	PIN_GRP_SPI1_SS_5 = 248,
	PIN_GRP_GEM_TSU0_0 = 249,
	PIN_GRP_GEM_TSU0_1 = 250,
	PIN_GRP_GEM_TSU0_2 = 251,
	PIN_GRP_GEM_TSU0_3 = 252,
	PIN_GRP_OSPI0_SS_0 = 253,
	PIN_GRP_QSPI0_SS_0 = 254,
	PIN_GRP_TEST_CLK_0 = 255,
	PIN_GRP_TTC0_CLK_0 = 256,
	PIN_GRP_TTC0_CLK_1 = 257,
	PIN_GRP_TTC0_CLK_2 = 258,
	PIN_GRP_TTC0_CLK_3 = 259,
	PIN_GRP_TTC0_CLK_4 = 260,
	PIN_GRP_TTC0_CLK_5 = 261,
	PIN_GRP_TTC0_CLK_6 = 262,
	PIN_GRP_TTC0_CLK_7 = 263,
	PIN_GRP_TTC0_CLK_8 = 264,
	PIN_GRP_TTC0_WAV_0 = 265,
	PIN_GRP_TTC0_WAV_1 = 266,
	PIN_GRP_TTC0_WAV_2 = 267,
	PIN_GRP_TTC0_WAV_3 = 268,
	PIN_GRP_TTC0_WAV_4 = 269,
	PIN_GRP_TTC0_WAV_5 = 270,
	PIN_GRP_TTC0_WAV_6 = 271,
	PIN_GRP_TTC0_WAV_7 = 272,
	PIN_GRP_TTC0_WAV_8 = 273,
	PIN_GRP_TTC1_CLK_0 = 274,
	PIN_GRP_TTC1_CLK_1 = 275,
	PIN_GRP_TTC1_CLK_2 = 276,
	PIN_GRP_TTC1_CLK_3 = 277,
	PIN_GRP_TTC1_CLK_4 = 278,
	PIN_GRP_TTC1_CLK_5 = 279,
	PIN_GRP_TTC1_CLK_6 = 280,
	PIN_GRP_TTC1_CLK_7 = 281,
	PIN_GRP_TTC1_CLK_8 = 282,
	PIN_GRP_TTC1_WAV_0 = 283,
	PIN_GRP_TTC1_WAV_1 = 284,
	PIN_GRP_TTC1_WAV_2 = 285,
	PIN_GRP_TTC1_WAV_3 = 286,
	PIN_GRP_TTC1_WAV_4 = 287,
	PIN_GRP_TTC1_WAV_5 = 288,
	PIN_GRP_TTC1_WAV_6 = 289,
	PIN_GRP_TTC1_WAV_7 = 290,
	PIN_GRP_TTC1_WAV_8 = 291,
	PIN_GRP_TTC2_CLK_0 = 292,
	PIN_GRP_TTC2_CLK_1 = 293,
	PIN_GRP_TTC2_CLK_2 = 294,
	PIN_GRP_TTC2_CLK_3 = 295,
	PIN_GRP_TTC2_CLK_4 = 296,
	PIN_GRP_TTC2_CLK_5 = 297,
	PIN_GRP_TTC2_CLK_6 = 298,
	PIN_GRP_TTC2_CLK_7 = 299,
	PIN_GRP_TTC2_CLK_8 = 300,
	PIN_GRP_TTC2_WAV_0 = 301,
	PIN_GRP_TTC2_WAV_1 = 302,
	PIN_GRP_TTC2_WAV_2 = 303,
	PIN_GRP_TTC2_WAV_3 = 304,
	PIN_GRP_TTC2_WAV_4 = 305,
	PIN_GRP_TTC2_WAV_5 = 306,
	PIN_GRP_TTC2_WAV_6 = 307,
	PIN_GRP_TTC2_WAV_7 = 308,
	PIN_GRP_TTC2_WAV_8 = 309,
	PIN_GRP_TTC3_CLK_0 = 310,
	PIN_GRP_TTC3_CLK_1 = 311,
	PIN_GRP_TTC3_CLK_2 = 312,
	PIN_GRP_TTC3_CLK_3 = 313,
	PIN_GRP_TTC3_CLK_4 = 314,
	PIN_GRP_TTC3_CLK_5 = 315,
	PIN_GRP_TTC3_CLK_6 = 316,
	PIN_GRP_TTC3_CLK_7 = 317,
	PIN_GRP_TTC3_CLK_8 = 318,
	PIN_GRP_TTC3_WAV_0 = 319,
	PIN_GRP_TTC3_WAV_1 = 320,
	PIN_GRP_TTC3_WAV_2 = 321,
	PIN_GRP_TTC3_WAV_3 = 322,
	PIN_GRP_TTC3_WAV_4 = 323,
	PIN_GRP_TTC3_WAV_5 = 324,
	PIN_GRP_TTC3_WAV_6 = 325,
	PIN_GRP_TTC3_WAV_7 = 326,
	PIN_GRP_TTC3_WAV_8 = 327,
	PIN_GRP_TEST_SCAN_0 = 328,
	PIN_GRP_TRACE0_CLK_0 = 329,
	PIN_GRP_TRACE0_CLK_1 = 330,
	PIN_GRP_TRACE0_CLK_2 = 331,
	PIN_GRP_UART0_CTRL_0 = 332,
	PIN_GRP_UART0_CTRL_1 = 333,
	PIN_GRP_UART0_CTRL_2 = 334,
	PIN_GRP_UART0_CTRL_3 = 335,
	PIN_GRP_UART0_CTRL_4 = 336,
	PIN_GRP_UART0_CTRL_5 = 337,
	PIN_GRP_UART0_CTRL_6 = 338,
	PIN_GRP_UART0_CTRL_7 = 339,
	PIN_GRP_UART0_CTRL_8 = 340,
	PIN_GRP_UART1_CTRL_0 = 341,
	PIN_GRP_UART1_CTRL_1 = 342,
	PIN_GRP_UART1_CTRL_2 = 343,
	PIN_GRP_UART1_CTRL_3 = 344,
	PIN_GRP_UART1_CTRL_4 = 345,
	PIN_GRP_UART1_CTRL_5 = 346,
	PIN_GRP_UART1_CTRL_6 = 347,
	PIN_GRP_UART1_CTRL_7 = 348,
	PIN_GRP_UART1_CTRL_8 = 349,
	PIN_GRP_OSPI0_RST_N_0 = 350,
	PIN_GRP_QSPI0_FBCLK_0 = 351,
	PIN_GRP_SYSMON_I2C0_0 = 352,
	PIN_GRP_SYSMON_I2C0_1 = 353,
	PIN_GRP_SYSMON_I2C0_2 = 354,
	PIN_GRP_SYSMON_I2C0_3 = 355,
	PIN_GRP_SYSMON_I2C0_4 = 356,
	PIN_GRP_SYSMON_I2C0_5 = 357,
	PIN_GRP_SYSMON_I2C0_6 = 358,
	PIN_GRP_SYSMON_I2C0_7 = 359,
	PIN_GRP_SYSMON_I2C0_8 = 360,
	PIN_GRP_SYSMON_I2C0_9 = 361,
	PIN_GRP_SYSMON_I2C0_10 = 362,
	PIN_GRP_SYSMON_I2C0_11 = 363,
	PIN_GRP_SYSMON_I2C0_12 = 364,
	PIN_GRP_SYSMON_I2C0_13 = 365,
	PIN_GRP_SYSMON_I2C0_14 = 366,
	PIN_GRP_SYSMON_I2C0_15 = 367,
	PIN_GRP_SYSMON_I2C0_16 = 368,
	PIN_GRP_SYSMON_I2C0_17 = 369,
	PIN_GRP_OSPI0_ECC_FAIL_0 = 370,
	PIN_GRP_OSPI0_ECC_FAIL_1 = 371,
	PIN_GRP_TAMPER_TRIGGER_0 = 372,
	PIN_GRP_TAMPER_TRIGGER_1 = 373,
	PIN_GRP_TAMPER_TRIGGER_2 = 374,
	PIN_GRP_TAMPER_TRIGGER_3 = 375,
	PIN_GRP_TAMPER_TRIGGER_4 = 376,
	PIN_GRP_TAMPER_TRIGGER_5 = 377,
	PIN_GRP_TAMPER_TRIGGER_6 = 378,
	PIN_GRP_TAMPER_TRIGGER_7 = 379,
	PIN_GRP_SYSMON_I2C0_ALRT_0 = 380,
	PIN_GRP_SYSMON_I2C0_ALRT_1 = 381,
	PIN_GRP_SYSMON_I2C0_ALRT_2 = 382,
	PIN_GRP_SYSMON_I2C0_ALRT_3 = 383,
	PIN_GRP_SYSMON_I2C0_ALRT_4 = 384,
	PIN_GRP_SYSMON_I2C0_ALRT_5 = 385,
	PIN_GRP_SYSMON_I2C0_ALRT_6 = 386,
	PIN_GRP_SYSMON_I2C0_ALRT_7 = 387,
	PIN_GRP_SYSMON_I2C0_ALRT_8 = 388,
	PIN_GRP_SYSMON_I2C0_ALRT_9 = 389,
	PIN_GRP_SYSMON_I2C0_ALRT_10 = 390,
	PIN_GRP_SYSMON_I2C0_ALRT_11 = 391,
	PIN_GRP_SYSMON_I2C0_ALRT_12 = 392,
	PIN_GRP_SYSMON_I2C0_ALRT_13 = 393,
	PIN_GRP_SYSMON_I2C0_ALRT_14 = 394,
	PIN_GRP_SYSMON_I2C0_ALRT_15 = 395,
	PIN_GRP_SYSMON_I2C0_ALRT_16 = 396,
	PIN_GRP_SYSMON_I2C0_ALRT_17 = 397,
};
#ifdef __cplusplus
}
#endif

/** @} */
#endif /* XPM_PINFUNC_PLAT_H_ */
